@@ -1,7 +1,5 @@
 package Pod::Elemental::Autochomp;
-our $VERSION = '0.093280';
-
-
+our $VERSION = '0.100220';
 use namespace::autoclean;
 use Moose::Role;
 # ABSTRACT: a paragraph that chomps set content
@@ -9,10 +7,10 @@ use Moose::Role;
 use Pod::Elemental::Types qw(ChompedString);
 
 
-has '+content' => (
-  coerce => 1,
-  isa    => ChompedString,
-);
+# has '+content' => (
+#   coerce => 1,
+#   isa    => ChompedString,
+# );
 
 1;
 
@@ -25,7 +23,7 @@ Pod::Elemental::Autochomp - a paragraph that chomps set content
 
 =head1 VERSION
 
-version 0.093280
+version 0.100220
 
 =head1 OVERVIEW
 
@@ -38,7 +36,7 @@ transformer.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
