@@ -1,7 +1,5 @@
 package Pod::Elemental::Element::Nested;
-our $VERSION = '0.093280';
-
-
+our $VERSION = '0.100220';
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Command';
 with 'Pod::Elemental::Node';
@@ -12,6 +10,11 @@ use namespace::autoclean;
 
 use Moose::Autobox 0.10;
 
+# BEGIN Autochomp Replacement
+use Pod::Elemental::Types qw(ChompedString);
+has '+content' => (coerce => 1, isa => ChompedString);
+# END   Autochomp Replacement
+
 
 override as_pod_string => sub {
   my ($self) = @_;
@@ -38,7 +41,7 @@ Pod::Elemental::Element::Nested - an element that is a command and a node
 
 =head1 VERSION
 
-version 0.093280
+version 0.100220
 
 =head1 OVERVIEW
 
@@ -59,7 +62,7 @@ L<Pod::Elemental::Element::Pod5::Region>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
